@@ -1,5 +1,7 @@
 import json
 import io
+import os
+import subprocess
 
 def read_json_file(file_path):
     with open(file_path) as json_data:
@@ -19,6 +21,26 @@ def write_json_file(data, file_path):
         outfile.write(to_unicode(str_))
     return
 
+def git_commit(static_path, message, files = "."):
+    current_path = os.getcwd()
+    os.chdir(static_path)
+    subprocess.run(["git", "add", files])
+    subprocess.run(["git", "commit", "-m", message])
+    os.chdir(current_path)
+
+def yes_no(answer):
+    yes = set(['yes', 'y', 'ye', ''])
+    no = set(['no', 'n'])
+
+    while True:
+        choice = input(answer).lower()
+        if choice in yes:
+            return True
+        elif choice in no:
+            return False
+        else:
+            print("Please respond with 'yes' or 'no'\n")
+
 def bump_version(file_path, position):
   package_json = read_json_file(file_path)
   version = package_json["version"]
